Operations on the /groups resource.
Examples
{:ok, %{"value" => groups}} = GraphApi.Groups.list()
{:ok, group} = GraphApi.Groups.get("group-id")
{:ok, %{"value" => members}} = GraphApi.Groups.list_members("group-id")
Summary
Functions
Adds an app role assignment to a group.
Batch query variant of add_app_role_assignment/3.
Adds a member to a group.
Batch query variant of add_member/3.
Adds an owner to a group.
Batch query variant of add_owner/3.
Assigns licenses to a group.
Batch query variant of assign_license/3.
Checks whether the group is a member of the specified groups.
Batch query variant of check_member_groups/3.
Checks whether the group is a member of the specified objects.
Batch query variant of check_member_objects/3.
Creates a new group.
Batch query variant of create/2.
Deletes a group.
Batch query variant of delete/2.
Delta query for groups. Returns changes since the last sync.
Batch query variant of delta/1.
Gets a group by ID.
Returns all group IDs the group is a member of (transitive).
Batch query variant of get_member_groups/3.
Returns all group and directory role IDs the group is a member of (transitive).
Batch query variant of get_member_objects/3.
Batch query variant of get/2.
Lists groups in the organization.
Lists app role assignments for a group.
Batch query variant of list_app_role_assignments/2.
Lists groups and directory roles the group is a member of.
Batch query variant of list_member_of/2.
Lists members of a group.
Batch query variant of list_members/2.
Lists owners of a group.
Batch query variant of list_owners/2.
Lists resource-specific permission grants on a group.
Batch query variant of list_permission_grants/2.
Batch query variant of list/1.
Lists groups and directory roles the group is a transitive member of.
Batch query variant of list_transitive_member_of/2.
Lists transitive members of a group.
Batch query variant of list_transitive_members/2.
Delta query for group membership. Returns member changes since the last sync.
Batch query variant of members_delta/2.
Removes an app role assignment from a group.
Batch query variant of remove_app_role_assignment/3.
Removes a member from a group.
Batch query variant of remove_member/3.
Removes an owner from a group.
Batch query variant of remove_owner/3.
Renews a group's expiration.
Batch query variant of renew/2.
Updates a group.
Batch query variant of update/3.
Functions
Adds an app role assignment to a group.
@spec add_app_role_assignment_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of add_app_role_assignment/3.
Adds a member to a group.
The member_id should be the directory object ID of the user or service principal.
@spec add_member_query(String.t(), String.t(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of add_member/3.
Adds an owner to a group.
The owner_id should be the directory object ID of the user.
@spec add_owner_query(String.t(), String.t(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of add_owner/3.
Assigns licenses to a group.
@spec assign_license_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of assign_license/3.
Checks whether the group is a member of the specified groups.
@spec check_member_groups_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of check_member_groups/3.
Checks whether the group is a member of the specified objects.
@spec check_member_objects_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of check_member_objects/3.
Creates a new group.
@spec create_query( map(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of create/2.
Deletes a group.
@spec delete_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of delete/2.
@spec delta(keyword()) :: {:ok, GraphApi.Delta.delta_page()} | {:error, term()}
Delta query for groups. Returns changes since the last sync.
See GraphApi.Delta for details.
@spec delta_query(keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of delta/1.
Gets a group by ID.
Returns all group IDs the group is a member of (transitive).
@spec get_member_groups_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of get_member_groups/3.
Returns all group and directory role IDs the group is a member of (transitive).
@spec get_member_objects_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of get_member_objects/3.
@spec get_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of get/2.
Lists groups in the organization.
Lists app role assignments for a group.
@spec list_app_role_assignments_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_app_role_assignments/2.
Lists groups and directory roles the group is a member of.
@spec list_member_of_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_member_of/2.
Lists members of a group.
@spec list_members_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_members/2.
Lists owners of a group.
@spec list_owners_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_owners/2.
Lists resource-specific permission grants on a group.
@spec list_permission_grants_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_permission_grants/2.
@spec list_query(keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of list/1.
Lists groups and directory roles the group is a transitive member of.
@spec list_transitive_member_of_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_transitive_member_of/2.
Lists transitive members of a group.
@spec list_transitive_members_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of list_transitive_members/2.
@spec members_delta( String.t(), keyword() ) :: {:ok, GraphApi.Delta.delta_page()} | {:error, term()}
Delta query for group membership. Returns member changes since the last sync.
@spec members_delta_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of members_delta/2.
Removes an app role assignment from a group.
@spec remove_app_role_assignment_query(String.t(), String.t(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of remove_app_role_assignment/3.
Removes a member from a group.
@spec remove_member_query(String.t(), String.t(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of remove_member/3.
Removes an owner from a group.
@spec remove_owner_query(String.t(), String.t(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of remove_owner/3.
Renews a group's expiration.
@spec renew_query( String.t(), keyword() ) :: GraphApi.Batch.Request.t()
Batch query variant of renew/2.
Updates a group.
@spec update_query(String.t(), map(), keyword()) :: GraphApi.Batch.Request.t()
Batch query variant of update/3.